@@ -1399,10 +1399,13 @@ def descendant_selector_applies(element: Element, sel: str) -> None:
     for ancestor in ancestor_list:
         id = ancestor[1]
         ancestor_element = __get_element_by_id(id)
-        selector = selector_list[current_pos]
-        cur_selector_applies = does_selector_apply(ancestor_element, selector)
-        if cur_selector_applies:
-            selector_list = selector_list[1:]
+        if selector_list:
+            selector = selector_list[current_pos]
+            cur_selector_applies = does_selector_apply(
+                ancestor_element, selector
+            )
+            if cur_selector_applies:
+                selector_list = selector_list[1:]
     applies = not selector_list
     return applies
 
@@ -1536,6 +1539,16 @@ def targets_element_directly(element: Element, selector: str) -> bool:
     elif selector_type == "id_selector":
         attributes = element.attributes
         if attributes:
+            if not isinstance(attributes, dict):
+                try:
+                    attributes = dict(attributes)
+                except Exception:
+                    msg = "This is not a dictionary and cannot be converted"
+                    msg += " into one!"
+                    raise ValueError(msg)
+            else:
+                data_type = str(type(attributes))
+                print(data_type)
             id_attribute = attributes.get("id")
             if id_attribute:
                 targets = selector in attributes.get("id")
@@ -1841,11 +1854,12 @@ def get_color_contrast_details(tree: CSSAppliedTree, rating="AAA") -> list:
         for result in results:
             count = results.count(result)
             file, selector, element, size, rating = result
-            msg = f"fail: in {file}, selector: {selector} triggered {count} "
+            msg = f"fail: in {file}, element: <{element}> had {count} "
             if count > 1:
-                msg += f"contrast errors on <{element}> for {size} {rating}."
+                msg += f"contrast errors for {size} {rating} "
             else:
-                msg += f"contrast error on <{element}> for {size} {rating}."
+                msg += f"contrast error for {size} {rating} "
+            msg += f"triggered by selector {selector}."
             if msg not in adjusted:
                 adjusted.append(msg)
         results = adjusted
