@@ -313,7 +313,7 @@ def has_alpha_channel(code: str) -> bool:
     """
     has_alpha = False
     if "#" in code:
-        if len(code) == 9:
+        if len(code) == 9 or len(code) == 5:
             has_alpha = True
     if "hsla(" in code:
         has_alpha = True
@@ -321,6 +321,10 @@ def has_alpha_channel(code: str) -> bool:
         has_alpha = True
     if "rgba(" in code:
         has_alpha = True
+    if "rgb" in code and "/" in code:
+        has_alpha = True
+    if "transparent" in code:
+        has_alpha = True
     return has_alpha
 
 
@@ -409,7 +413,7 @@ def hex_to_decimal(c: str) -> int:
         msg += "2 digits"
         raise ValueError(msg)
     if c[0].lower() not in hex_map.keys():
-        raise ValueError(f"The value `{c}` is not a valid hex code.")
+        raise ValueError(f"The value {repr(c)} is not a valid hex code.")
     c = c.lower()
     ones = hex_map[c[1]]
     sixteens = hex_map[c[0]] * 16
@@ -613,11 +617,9 @@ def contrast_ratio(hex1: str, hex2: str) -> float:
         l1 = l2
         l2 = temp
     ratio = (l1 + 0.05) / (l2 + 0.05)
-    # get the ratio to 2 decimal places without rounding
-    ratio_string = str(ratio)
-    dot_pos = ratio_string.index(".")
-    ratio_string = ratio_string[: dot_pos + 3]
-    return float(ratio_string)
+    # round to 1 decimal place
+    ratio = round(ratio, 1)
+    return ratio
 
 
 def get_color_type(code: str) -> str:
